# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!  You can find all relevant documentation here: https://github.com/carbon3d/carbon3d-api   # noqa: E501

    The version of the OpenAPI document: 0.2.7
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from carbon3d.configuration import Configuration


class PartOrdersResponsePartOrders(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'uuid': 'str',
        'status': 'PartOrderStatus',
        'part_order_number': 'str',
        'printed_parts_count': 'int',
        'due_date': 'datetime',
        'flushed_at': 'datetime',
        'build_uuids': 'list[str]'
    }

    attribute_map = {
        'uuid': 'uuid',
        'status': 'status',
        'part_order_number': 'part_order_number',
        'printed_parts_count': 'printed_parts_count',
        'due_date': 'due_date',
        'flushed_at': 'flushed_at',
        'build_uuids': 'build_uuids'
    }

    def __init__(self, uuid=None, status=None, part_order_number=None, printed_parts_count=None, due_date=None, flushed_at=None, build_uuids=None, local_vars_configuration=None):  # noqa: E501
        """PartOrdersResponsePartOrders - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._uuid = None
        self._status = None
        self._part_order_number = None
        self._printed_parts_count = None
        self._due_date = None
        self._flushed_at = None
        self._build_uuids = None
        self.discriminator = None

        if uuid is not None:
            self.uuid = uuid
        if status is not None:
            self.status = status
        if part_order_number is not None:
            self.part_order_number = part_order_number
        if printed_parts_count is not None:
            self.printed_parts_count = printed_parts_count
        if due_date is not None:
            self.due_date = due_date
        if flushed_at is not None:
            self.flushed_at = flushed_at
        if build_uuids is not None:
            self.build_uuids = build_uuids

    @property
    def uuid(self):
        """Gets the uuid of this PartOrdersResponsePartOrders.  # noqa: E501

        PartOrder UUID  # noqa: E501

        :return: The uuid of this PartOrdersResponsePartOrders.  # noqa: E501
        :rtype: str
        """
        return self._uuid

    @uuid.setter
    def uuid(self, uuid):
        """Sets the uuid of this PartOrdersResponsePartOrders.

        PartOrder UUID  # noqa: E501

        :param uuid: The uuid of this PartOrdersResponsePartOrders.  # noqa: E501
        :type: str
        """

        self._uuid = uuid

    @property
    def status(self):
        """Gets the status of this PartOrdersResponsePartOrders.  # noqa: E501


        :return: The status of this PartOrdersResponsePartOrders.  # noqa: E501
        :rtype: PartOrderStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this PartOrdersResponsePartOrders.


        :param status: The status of this PartOrdersResponsePartOrders.  # noqa: E501
        :type: PartOrderStatus
        """

        self._status = status

    @property
    def part_order_number(self):
        """Gets the part_order_number of this PartOrdersResponsePartOrders.  # noqa: E501

        Customer-provided part order number  # noqa: E501

        :return: The part_order_number of this PartOrdersResponsePartOrders.  # noqa: E501
        :rtype: str
        """
        return self._part_order_number

    @part_order_number.setter
    def part_order_number(self, part_order_number):
        """Sets the part_order_number of this PartOrdersResponsePartOrders.

        Customer-provided part order number  # noqa: E501

        :param part_order_number: The part_order_number of this PartOrdersResponsePartOrders.  # noqa: E501
        :type: str
        """

        self._part_order_number = part_order_number

    @property
    def printed_parts_count(self):
        """Gets the printed_parts_count of this PartOrdersResponsePartOrders.  # noqa: E501

        Quantity of printed parts in the part order  # noqa: E501

        :return: The printed_parts_count of this PartOrdersResponsePartOrders.  # noqa: E501
        :rtype: int
        """
        return self._printed_parts_count

    @printed_parts_count.setter
    def printed_parts_count(self, printed_parts_count):
        """Sets the printed_parts_count of this PartOrdersResponsePartOrders.

        Quantity of printed parts in the part order  # noqa: E501

        :param printed_parts_count: The printed_parts_count of this PartOrdersResponsePartOrders.  # noqa: E501
        :type: int
        """

        self._printed_parts_count = printed_parts_count

    @property
    def due_date(self):
        """Gets the due_date of this PartOrdersResponsePartOrders.  # noqa: E501

        Print due date, used to prioritize part orders for packing and printing  # noqa: E501

        :return: The due_date of this PartOrdersResponsePartOrders.  # noqa: E501
        :rtype: datetime
        """
        return self._due_date

    @due_date.setter
    def due_date(self, due_date):
        """Sets the due_date of this PartOrdersResponsePartOrders.

        Print due date, used to prioritize part orders for packing and printing  # noqa: E501

        :param due_date: The due_date of this PartOrdersResponsePartOrders.  # noqa: E501
        :type: datetime
        """

        self._due_date = due_date

    @property
    def flushed_at(self):
        """Gets the flushed_at of this PartOrdersResponsePartOrders.  # noqa: E501

        When the part order was flushed through the packer, or null if it is not flushed.  # noqa: E501

        :return: The flushed_at of this PartOrdersResponsePartOrders.  # noqa: E501
        :rtype: datetime
        """
        return self._flushed_at

    @flushed_at.setter
    def flushed_at(self, flushed_at):
        """Sets the flushed_at of this PartOrdersResponsePartOrders.

        When the part order was flushed through the packer, or null if it is not flushed.  # noqa: E501

        :param flushed_at: The flushed_at of this PartOrdersResponsePartOrders.  # noqa: E501
        :type: datetime
        """

        self._flushed_at = flushed_at

    @property
    def build_uuids(self):
        """Gets the build_uuids of this PartOrdersResponsePartOrders.  # noqa: E501

        Builds which contain printed parts from this part order.  # noqa: E501

        :return: The build_uuids of this PartOrdersResponsePartOrders.  # noqa: E501
        :rtype: list[str]
        """
        return self._build_uuids

    @build_uuids.setter
    def build_uuids(self, build_uuids):
        """Sets the build_uuids of this PartOrdersResponsePartOrders.

        Builds which contain printed parts from this part order.  # noqa: E501

        :param build_uuids: The build_uuids of this PartOrdersResponsePartOrders.  # noqa: E501
        :type: list[str]
        """

        self._build_uuids = build_uuids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PartOrdersResponsePartOrders):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PartOrdersResponsePartOrders):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!  You can find all relevant documentation here: https://github.com/carbon3d/carbon3d-api   # noqa: E501

    The version of the OpenAPI document: 0.2.7
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import carbon3d
from carbon3d.models.model_print import ModelPrint  # noqa: E501
from carbon3d.rest import ApiException

class TestModelPrint(unittest.TestCase):
    """ModelPrint unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ModelPrint
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = carbon3d.models.model_print.ModelPrint()  # noqa: E501
        if include_optional :
            return ModelPrint(
                name = '0', 
                print_id = '0', 
                uuid = '0', 
                build_uuid = '0', 
                finished_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                remaining_sec = 56, 
                printed_by = '0', 
                print_order_uuid = '0', 
                print_order_number = '0', 
                status = '0', 
                origin = carbon3d.models.print_origin.Print_origin(
                    cassette_serial = '0', 
                    cassette_nfc_uid = '0', 
                    platform_serial = '0', 
                    platform_nfc_uid = '0', 
                    printer_serial = '0', 
                    software_version = '0', ), 
                config = carbon3d.models.print_config.Print_config(
                    resin_name = '0', 
                    print_profile = '0', 
                    release_film_nm = 56, 
                    slice_thickness_nm = 56, ), 
                metrics = carbon3d.models.print_metrics.Print_metrics(
                    average_speed_mmhr = 56, 
                    consumed_resin_volume_ml = 1.337, 
                    minimum_required_resin_volume_ml = 1.337, 
                    estimated_total_resin_volume_ml = 1.337, 
                    measured_resin_volume_ml = 1.337, ), 
                feedback = carbon3d.models.print_feedback.Print_feedback(
                    feedback_rating = 1.337, 
                    feedback_message = '0', )
            )
        else :
            return ModelPrint(
        )

    def testModelPrint(self):
        """Test ModelPrint"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!  You can find all relevant documentation here: https://github.com/carbon3d/carbon3d-api   # noqa: E501

    The version of the OpenAPI document: 0.2.7
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from carbon3d.configuration import Configuration


class PartOrderRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'part_order_number': 'str',
        'parts': 'list[PartOrderRequestParts]',
        'due_date': 'datetime',
        'flush': 'bool'
    }

    attribute_map = {
        'part_order_number': 'part_order_number',
        'parts': 'parts',
        'due_date': 'due_date',
        'flush': 'flush'
    }

    def __init__(self, part_order_number=None, parts=None, due_date=None, flush=None, local_vars_configuration=None):  # noqa: E501
        """PartOrderRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._part_order_number = None
        self._parts = None
        self._due_date = None
        self._flush = None
        self.discriminator = None

        self.part_order_number = part_order_number
        self.parts = parts
        self.due_date = due_date
        if flush is not None:
            self.flush = flush

    @property
    def part_order_number(self):
        """Gets the part_order_number of this PartOrderRequest.  # noqa: E501

        Customer-provided part order number  # noqa: E501

        :return: The part_order_number of this PartOrderRequest.  # noqa: E501
        :rtype: str
        """
        return self._part_order_number

    @part_order_number.setter
    def part_order_number(self, part_order_number):
        """Sets the part_order_number of this PartOrderRequest.

        Customer-provided part order number  # noqa: E501

        :param part_order_number: The part_order_number of this PartOrderRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and part_order_number is None:  # noqa: E501
            raise ValueError("Invalid value for `part_order_number`, must not be `None`")  # noqa: E501

        self._part_order_number = part_order_number

    @property
    def parts(self):
        """Gets the parts of this PartOrderRequest.  # noqa: E501

        Parts to be printed  # noqa: E501

        :return: The parts of this PartOrderRequest.  # noqa: E501
        :rtype: list[PartOrderRequestParts]
        """
        return self._parts

    @parts.setter
    def parts(self, parts):
        """Sets the parts of this PartOrderRequest.

        Parts to be printed  # noqa: E501

        :param parts: The parts of this PartOrderRequest.  # noqa: E501
        :type: list[PartOrderRequestParts]
        """
        if self.local_vars_configuration.client_side_validation and parts is None:  # noqa: E501
            raise ValueError("Invalid value for `parts`, must not be `None`")  # noqa: E501

        self._parts = parts

    @property
    def due_date(self):
        """Gets the due_date of this PartOrderRequest.  # noqa: E501

        Print due date, used to prioritize part orders for packing and printing  # noqa: E501

        :return: The due_date of this PartOrderRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._due_date

    @due_date.setter
    def due_date(self, due_date):
        """Sets the due_date of this PartOrderRequest.

        Print due date, used to prioritize part orders for packing and printing  # noqa: E501

        :param due_date: The due_date of this PartOrderRequest.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and due_date is None:  # noqa: E501
            raise ValueError("Invalid value for `due_date`, must not be `None`")  # noqa: E501

        self._due_date = due_date

    @property
    def flush(self):
        """Gets the flush of this PartOrderRequest.  # noqa: E501

        Push parts in a part order through the auto-packer.  # noqa: E501

        :return: The flush of this PartOrderRequest.  # noqa: E501
        :rtype: bool
        """
        return self._flush

    @flush.setter
    def flush(self, flush):
        """Sets the flush of this PartOrderRequest.

        Push parts in a part order through the auto-packer.  # noqa: E501

        :param flush: The flush of this PartOrderRequest.  # noqa: E501
        :type: bool
        """

        self._flush = flush

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PartOrderRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PartOrderRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!  You can find all relevant documentation here: https://github.com/carbon3d/carbon3d-api   # noqa: E501

    The version of the OpenAPI document: 0.2.7
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import carbon3d
from carbon3d.models.part_measurement_template import PartMeasurementTemplate  # noqa: E501
from carbon3d.rest import ApiException

class TestPartMeasurementTemplate(unittest.TestCase):
    """PartMeasurementTemplate unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PartMeasurementTemplate
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = carbon3d.models.part_measurement_template.PartMeasurementTemplate()  # noqa: E501
        if include_optional :
            return PartMeasurementTemplate(
                uuid = '0', 
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                production_sop_name = '0', 
                production_sop_version = 1.337, 
                operation_name = '0', 
                measurement_name = '0', 
                zones = [
                    '0'
                    ], 
                zones_enabled = True, 
                required_level = 'required', 
                measurement_type = 'process', 
                units = '0', 
                min = 1.337, 
                max = 1.337, 
                measurement_classification = '0', 
                category_options = carbon3d.models.part_measurement_template_category_options.PartMeasurementTemplate_category_options(
                    fail = [
                        '0'
                        ], 
                    flag = [
                        '0'
                        ], 
                    pass = [
                        '0'
                        ], )
            )
        else :
            return PartMeasurementTemplate(
        )

    def testPartMeasurementTemplate(self):
        """Test PartMeasurementTemplate"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!  You can find all relevant documentation here: https://github.com/carbon3d/carbon3d-api   # noqa: E501

    The version of the OpenAPI document: 0.2.7
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from carbon3d.configuration import Configuration


class PrintOrder(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'uuid': 'str',
        'build_uuid': 'str',
        'total_copies': 'int',
        'created_at': 'datetime',
        'print_order_number': 'str',
        'print_order_tags': 'dict(str, str)',
        'notes': 'str',
        'routed_to': 'dict(str, PrintOrderRoutedTo)'
    }

    attribute_map = {
        'uuid': 'uuid',
        'build_uuid': 'build_uuid',
        'total_copies': 'total_copies',
        'created_at': 'created_at',
        'print_order_number': 'print_order_number',
        'print_order_tags': 'print_order_tags',
        'notes': 'notes',
        'routed_to': 'routed_to'
    }

    def __init__(self, uuid=None, build_uuid=None, total_copies=1, created_at=None, print_order_number=None, print_order_tags=None, notes=None, routed_to=None, local_vars_configuration=None):  # noqa: E501
        """PrintOrder - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._uuid = None
        self._build_uuid = None
        self._total_copies = None
        self._created_at = None
        self._print_order_number = None
        self._print_order_tags = None
        self._notes = None
        self._routed_to = None
        self.discriminator = None

        if uuid is not None:
            self.uuid = uuid
        if build_uuid is not None:
            self.build_uuid = build_uuid
        if total_copies is not None:
            self.total_copies = total_copies
        if created_at is not None:
            self.created_at = created_at
        if print_order_number is not None:
            self.print_order_number = print_order_number
        if print_order_tags is not None:
            self.print_order_tags = print_order_tags
        if notes is not None:
            self.notes = notes
        if routed_to is not None:
            self.routed_to = routed_to

    @property
    def uuid(self):
        """Gets the uuid of this PrintOrder.  # noqa: E501

        The uuid of the print order  # noqa: E501

        :return: The uuid of this PrintOrder.  # noqa: E501
        :rtype: str
        """
        return self._uuid

    @uuid.setter
    def uuid(self, uuid):
        """Sets the uuid of this PrintOrder.

        The uuid of the print order  # noqa: E501

        :param uuid: The uuid of this PrintOrder.  # noqa: E501
        :type: str
        """

        self._uuid = uuid

    @property
    def build_uuid(self):
        """Gets the build_uuid of this PrintOrder.  # noqa: E501

        The uuid of the build to be queued  # noqa: E501

        :return: The build_uuid of this PrintOrder.  # noqa: E501
        :rtype: str
        """
        return self._build_uuid

    @build_uuid.setter
    def build_uuid(self, build_uuid):
        """Sets the build_uuid of this PrintOrder.

        The uuid of the build to be queued  # noqa: E501

        :param build_uuid: The build_uuid of this PrintOrder.  # noqa: E501
        :type: str
        """

        self._build_uuid = build_uuid

    @property
    def total_copies(self):
        """Gets the total_copies of this PrintOrder.  # noqa: E501

        The total number of copies to be printed  # noqa: E501

        :return: The total_copies of this PrintOrder.  # noqa: E501
        :rtype: int
        """
        return self._total_copies

    @total_copies.setter
    def total_copies(self, total_copies):
        """Sets the total_copies of this PrintOrder.

        The total number of copies to be printed  # noqa: E501

        :param total_copies: The total_copies of this PrintOrder.  # noqa: E501
        :type: int
        """

        self._total_copies = total_copies

    @property
    def created_at(self):
        """Gets the created_at of this PrintOrder.  # noqa: E501

        Time when print order was created  # noqa: E501

        :return: The created_at of this PrintOrder.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this PrintOrder.

        Time when print order was created  # noqa: E501

        :param created_at: The created_at of this PrintOrder.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def print_order_number(self):
        """Gets the print_order_number of this PrintOrder.  # noqa: E501

        Customer-provided print order number  # noqa: E501

        :return: The print_order_number of this PrintOrder.  # noqa: E501
        :rtype: str
        """
        return self._print_order_number

    @print_order_number.setter
    def print_order_number(self, print_order_number):
        """Sets the print_order_number of this PrintOrder.

        Customer-provided print order number  # noqa: E501

        :param print_order_number: The print_order_number of this PrintOrder.  # noqa: E501
        :type: str
        """

        self._print_order_number = print_order_number

    @property
    def print_order_tags(self):
        """Gets the print_order_tags of this PrintOrder.  # noqa: E501

        Key value pairs to be associated with print order  # noqa: E501

        :return: The print_order_tags of this PrintOrder.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._print_order_tags

    @print_order_tags.setter
    def print_order_tags(self, print_order_tags):
        """Sets the print_order_tags of this PrintOrder.

        Key value pairs to be associated with print order  # noqa: E501

        :param print_order_tags: The print_order_tags of this PrintOrder.  # noqa: E501
        :type: dict(str, str)
        """

        self._print_order_tags = print_order_tags

    @property
    def notes(self):
        """Gets the notes of this PrintOrder.  # noqa: E501

        Notes associated with  # noqa: E501

        :return: The notes of this PrintOrder.  # noqa: E501
        :rtype: str
        """
        return self._notes

    @notes.setter
    def notes(self, notes):
        """Sets the notes of this PrintOrder.

        Notes associated with  # noqa: E501

        :param notes: The notes of this PrintOrder.  # noqa: E501
        :type: str
        """

        self._notes = notes

    @property
    def routed_to(self):
        """Gets the routed_to of this PrintOrder.  # noqa: E501

        Printers that this print order was routed to, keyed off printer serial number  # noqa: E501

        :return: The routed_to of this PrintOrder.  # noqa: E501
        :rtype: dict(str, PrintOrderRoutedTo)
        """
        return self._routed_to

    @routed_to.setter
    def routed_to(self, routed_to):
        """Sets the routed_to of this PrintOrder.

        Printers that this print order was routed to, keyed off printer serial number  # noqa: E501

        :param routed_to: The routed_to of this PrintOrder.  # noqa: E501
        :type: dict(str, PrintOrderRoutedTo)
        """

        self._routed_to = routed_to

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PrintOrder):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PrintOrder):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!  You can find all relevant documentation here: https://github.com/carbon3d/carbon3d-api   # noqa: E501

    The version of the OpenAPI document: 0.2.7
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from carbon3d.api_client import ApiClient
from carbon3d.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class PrintersApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_printer(self, serial, **kwargs):  # noqa: E501
        """Get a specific printer's status information  # noqa: E501

        Fetch printer status  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_printer(serial, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str serial: e.g. 3P01CM (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Printer
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_printer_with_http_info(serial, **kwargs)  # noqa: E501

    def get_printer_with_http_info(self, serial, **kwargs):  # noqa: E501
        """Get a specific printer's status information  # noqa: E501

        Fetch printer status  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_printer_with_http_info(serial, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str serial: e.g. 3P01CM (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Printer, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'serial'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_printer" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'serial' is set
        if self.api_client.client_side_validation and ('serial' not in local_var_params or  # noqa: E501
                                                        local_var_params['serial'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `serial` when calling `get_printer`")  # noqa: E501

        if self.api_client.client_side_validation and 'serial' in local_var_params and not re.search(r'^([0-9A-Z]{6,7})$', local_var_params['serial']):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `serial` when calling `get_printer`, must conform to the pattern `/^([0-9A-Z]{6,7})$/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'serial' in local_var_params:
            path_params['serial'] = local_var_params['serial']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/printers/{serial}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Printer',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_printers(self, limit, offset, **kwargs):  # noqa: E501
        """Fetch all printer's status information  # noqa: E501

        Fetch all printers and their relevant attached information like status and sliding print window (past/current/next). Sorted by name, ascending.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_printers(limit, offset, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int limit: Max records to return (required)
        :param int offset: Number of items to skip (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: PrintersResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_printers_with_http_info(limit, offset, **kwargs)  # noqa: E501

    def get_printers_with_http_info(self, limit, offset, **kwargs):  # noqa: E501
        """Fetch all printer's status information  # noqa: E501

        Fetch all printers and their relevant attached information like status and sliding print window (past/current/next). Sorted by name, ascending.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_printers_with_http_info(limit, offset, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int limit: Max records to return (required)
        :param int offset: Number of items to skip (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(PrintersResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'limit',
            'offset'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_printers" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'limit' is set
        if self.api_client.client_side_validation and ('limit' not in local_var_params or  # noqa: E501
                                                        local_var_params['limit'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `limit` when calling `get_printers`")  # noqa: E501
        # verify the required parameter 'offset' is set
        if self.api_client.client_side_validation and ('offset' not in local_var_params or  # noqa: E501
                                                        local_var_params['offset'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `offset` when calling `get_printers`")  # noqa: E501

        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] > 1000:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `get_printers`, must be a value less than or equal to `1000`")  # noqa: E501
        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] < 1:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `get_printers`, must be a value greater than or equal to `1`")  # noqa: E501
        if self.api_client.client_side_validation and 'offset' in local_var_params and local_var_params['offset'] < 0:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `offset` when calling `get_printers`, must be a value greater than or equal to `0`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'offset' in local_var_params and local_var_params['offset'] is not None:  # noqa: E501
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/printers', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PrintersResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!  You can find all relevant documentation here: https://github.com/carbon3d/carbon3d-api   # noqa: E501

    The version of the OpenAPI document: 0.2.7
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from carbon3d.api_client import ApiClient
from carbon3d.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class PrintsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_prints(self, limit, **kwargs):  # noqa: E501
        """List finished prints information  # noqa: E501

        Fetch prints  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_prints(limit, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int limit: Max records to return (required)
        :param str cursor: Cursor for paginating through data (e.g. dXNlcjpXMDdRQ1JQQTQ=d)
        :param list[str] uuid: An array of UUIDs
        :param list[int] application_id: An array of Application IDs
        :param list[str] application_uuid: An array of Application UUIDs
        :param str started_before: Print started before timestamp (exclusive)
        :param str started_after: Print started at or after timestamp (inclusive)
        :param str finished_before: Print finished before timestamp (exclusive)
        :param str finished_after: Print finished at or after timestamp (inclusive)
        :param list[str] print_id: An array of Print IDs
        :param list[str] status: An array of statuses
        :param list[str] print_order_number: An array of number(s) of the print_order submitted
        :param list[str] print_order_uuid: An array of UUID(s) of the print_order submitted
        :param list[str] printer_serial: An array of serials of the Printer(s) used to print
        :param list[str] printer_name: An array of names of the Printer(s) used to print
        :param list[str] platform_serial: An array of names of the Printer(s) used to print
        :param list[str] sort: Field(s) to sort by. Ascending order by default, use `sort=field,desc` to specify descending order. Sortable fields are: `uuid`, `status`, `started_at`, `finished_at`, `print_order_number`
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: PrintsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_prints_with_http_info(limit, **kwargs)  # noqa: E501

    def get_prints_with_http_info(self, limit, **kwargs):  # noqa: E501
        """List finished prints information  # noqa: E501

        Fetch prints  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_prints_with_http_info(limit, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int limit: Max records to return (required)
        :param str cursor: Cursor for paginating through data (e.g. dXNlcjpXMDdRQ1JQQTQ=d)
        :param list[str] uuid: An array of UUIDs
        :param list[int] application_id: An array of Application IDs
        :param list[str] application_uuid: An array of Application UUIDs
        :param str started_before: Print started before timestamp (exclusive)
        :param str started_after: Print started at or after timestamp (inclusive)
        :param str finished_before: Print finished before timestamp (exclusive)
        :param str finished_after: Print finished at or after timestamp (inclusive)
        :param list[str] print_id: An array of Print IDs
        :param list[str] status: An array of statuses
        :param list[str] print_order_number: An array of number(s) of the print_order submitted
        :param list[str] print_order_uuid: An array of UUID(s) of the print_order submitted
        :param list[str] printer_serial: An array of serials of the Printer(s) used to print
        :param list[str] printer_name: An array of names of the Printer(s) used to print
        :param list[str] platform_serial: An array of names of the Printer(s) used to print
        :param list[str] sort: Field(s) to sort by. Ascending order by default, use `sort=field,desc` to specify descending order. Sortable fields are: `uuid`, `status`, `started_at`, `finished_at`, `print_order_number`
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(PrintsResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'limit',
            'cursor',
            'uuid',
            'application_id',
            'application_uuid',
            'started_before',
            'started_after',
            'finished_before',
            'finished_after',
            'print_id',
            'status',
            'print_order_number',
            'print_order_uuid',
            'printer_serial',
            'printer_name',
            'platform_serial',
            'sort'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_prints" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'limit' is set
        if self.api_client.client_side_validation and ('limit' not in local_var_params or  # noqa: E501
                                                        local_var_params['limit'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `limit` when calling `get_prints`")  # noqa: E501

        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] > 1000:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `get_prints`, must be a value less than or equal to `1000`")  # noqa: E501
        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] < 1:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `get_prints`, must be a value greater than or equal to `1`")  # noqa: E501
        if self.api_client.client_side_validation and ('uuid' in local_var_params and  # noqa: E501
                                                        len(local_var_params['uuid']) > 100):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `uuid` when calling `get_prints`, number of items must be less than or equal to `100`")  # noqa: E501
        if self.api_client.client_side_validation and ('uuid' in local_var_params and  # noqa: E501
                                                        len(local_var_params['uuid']) < 1):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `uuid` when calling `get_prints`, number of items must be greater than or equal to `1`")  # noqa: E501
        if self.api_client.client_side_validation and ('application_id' in local_var_params and  # noqa: E501
                                                        len(local_var_params['application_id']) > 100):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `application_id` when calling `get_prints`, number of items must be less than or equal to `100`")  # noqa: E501
        if self.api_client.client_side_validation and ('application_id' in local_var_params and  # noqa: E501
                                                        len(local_var_params['application_id']) < 1):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `application_id` when calling `get_prints`, number of items must be greater than or equal to `1`")  # noqa: E501
        if self.api_client.client_side_validation and ('application_uuid' in local_var_params and  # noqa: E501
                                                        len(local_var_params['application_uuid']) > 100):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `application_uuid` when calling `get_prints`, number of items must be less than or equal to `100`")  # noqa: E501
        if self.api_client.client_side_validation and ('application_uuid' in local_var_params and  # noqa: E501
                                                        len(local_var_params['application_uuid']) < 1):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `application_uuid` when calling `get_prints`, number of items must be greater than or equal to `1`")  # noqa: E501
        if self.api_client.client_side_validation and ('print_id' in local_var_params and  # noqa: E501
                                                        len(local_var_params['print_id']) > 100):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `print_id` when calling `get_prints`, number of items must be less than or equal to `100`")  # noqa: E501
        if self.api_client.client_side_validation and ('print_id' in local_var_params and  # noqa: E501
                                                        len(local_var_params['print_id']) < 1):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `print_id` when calling `get_prints`, number of items must be greater than or equal to `1`")  # noqa: E501
        if self.api_client.client_side_validation and ('status' in local_var_params and  # noqa: E501
                                                        len(local_var_params['status']) > 100):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `status` when calling `get_prints`, number of items must be less than or equal to `100`")  # noqa: E501
        if self.api_client.client_side_validation and ('status' in local_var_params and  # noqa: E501
                                                        len(local_var_params['status']) < 1):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `status` when calling `get_prints`, number of items must be greater than or equal to `1`")  # noqa: E501
        if self.api_client.client_side_validation and ('print_order_number' in local_var_params and  # noqa: E501
                                                        len(local_var_params['print_order_number']) > 100):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `print_order_number` when calling `get_prints`, number of items must be less than or equal to `100`")  # noqa: E501
        if self.api_client.client_side_validation and ('print_order_number' in local_var_params and  # noqa: E501
                                                        len(local_var_params['print_order_number']) < 1):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `print_order_number` when calling `get_prints`, number of items must be greater than or equal to `1`")  # noqa: E501
        if self.api_client.client_side_validation and ('print_order_uuid' in local_var_params and  # noqa: E501
                                                        len(local_var_params['print_order_uuid']) > 100):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `print_order_uuid` when calling `get_prints`, number of items must be less than or equal to `100`")  # noqa: E501
        if self.api_client.client_side_validation and ('print_order_uuid' in local_var_params and  # noqa: E501
                                                        len(local_var_params['print_order_uuid']) < 1):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `print_order_uuid` when calling `get_prints`, number of items must be greater than or equal to `1`")  # noqa: E501
        if self.api_client.client_side_validation and ('printer_serial' in local_var_params and  # noqa: E501
                                                        len(local_var_params['printer_serial']) > 100):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `printer_serial` when calling `get_prints`, number of items must be less than or equal to `100`")  # noqa: E501
        if self.api_client.client_side_validation and ('printer_serial' in local_var_params and  # noqa: E501
                                                        len(local_var_params['printer_serial']) < 1):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `printer_serial` when calling `get_prints`, number of items must be greater than or equal to `1`")  # noqa: E501
        if self.api_client.client_side_validation and ('printer_name' in local_var_params and  # noqa: E501
                                                        len(local_var_params['printer_name']) > 100):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `printer_name` when calling `get_prints`, number of items must be less than or equal to `100`")  # noqa: E501
        if self.api_client.client_side_validation and ('printer_name' in local_var_params and  # noqa: E501
                                                        len(local_var_params['printer_name']) < 1):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `printer_name` when calling `get_prints`, number of items must be greater than or equal to `1`")  # noqa: E501
        if self.api_client.client_side_validation and ('platform_serial' in local_var_params and  # noqa: E501
                                                        len(local_var_params['platform_serial']) > 100):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `platform_serial` when calling `get_prints`, number of items must be less than or equal to `100`")  # noqa: E501
        if self.api_client.client_side_validation and ('platform_serial' in local_var_params and  # noqa: E501
                                                        len(local_var_params['platform_serial']) < 1):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `platform_serial` when calling `get_prints`, number of items must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'cursor' in local_var_params and local_var_params['cursor'] is not None:  # noqa: E501
            query_params.append(('cursor', local_var_params['cursor']))  # noqa: E501
        if 'uuid' in local_var_params and local_var_params['uuid'] is not None:  # noqa: E501
            query_params.append(('uuid', local_var_params['uuid']))  # noqa: E501
            collection_formats['uuid'] = 'multi'  # noqa: E501
        if 'application_id' in local_var_params and local_var_params['application_id'] is not None:  # noqa: E501
            query_params.append(('application_id', local_var_params['application_id']))  # noqa: E501
            collection_formats['application_id'] = 'multi'  # noqa: E501
        if 'application_uuid' in local_var_params and local_var_params['application_uuid'] is not None:  # noqa: E501
            query_params.append(('application_uuid', local_var_params['application_uuid']))  # noqa: E501
            collection_formats['application_uuid'] = 'multi'  # noqa: E501
        if 'started_before' in local_var_params and local_var_params['started_before'] is not None:  # noqa: E501
            query_params.append(('started_before', local_var_params['started_before']))  # noqa: E501
        if 'started_after' in local_var_params and local_var_params['started_after'] is not None:  # noqa: E501
            query_params.append(('started_after', local_var_params['started_after']))  # noqa: E501
        if 'finished_before' in local_var_params and local_var_params['finished_before'] is not None:  # noqa: E501
            query_params.append(('finished_before', local_var_params['finished_before']))  # noqa: E501
        if 'finished_after' in local_var_params and local_var_params['finished_after'] is not None:  # noqa: E501
            query_params.append(('finished_after', local_var_params['finished_after']))  # noqa: E501
        if 'print_id' in local_var_params and local_var_params['print_id'] is not None:  # noqa: E501
            query_params.append(('print_id', local_var_params['print_id']))  # noqa: E501
            collection_formats['print_id'] = 'multi'  # noqa: E501
        if 'status' in local_var_params and local_var_params['status'] is not None:  # noqa: E501
            query_params.append(('status', local_var_params['status']))  # noqa: E501
            collection_formats['status'] = 'multi'  # noqa: E501
        if 'print_order_number' in local_var_params and local_var_params['print_order_number'] is not None:  # noqa: E501
            query_params.append(('print_order_number', local_var_params['print_order_number']))  # noqa: E501
            collection_formats['print_order_number'] = 'multi'  # noqa: E501
        if 'print_order_uuid' in local_var_params and local_var_params['print_order_uuid'] is not None:  # noqa: E501
            query_params.append(('print_order_uuid', local_var_params['print_order_uuid']))  # noqa: E501
            collection_formats['print_order_uuid'] = 'multi'  # noqa: E501
        if 'printer_serial' in local_var_params and local_var_params['printer_serial'] is not None:  # noqa: E501
            query_params.append(('printer_serial', local_var_params['printer_serial']))  # noqa: E501
            collection_formats['printer_serial'] = 'multi'  # noqa: E501
        if 'printer_name' in local_var_params and local_var_params['printer_name'] is not None:  # noqa: E501
            query_params.append(('printer_name', local_var_params['printer_name']))  # noqa: E501
            collection_formats['printer_name'] = 'multi'  # noqa: E501
        if 'platform_serial' in local_var_params and local_var_params['platform_serial'] is not None:  # noqa: E501
            query_params.append(('platform_serial', local_var_params['platform_serial']))  # noqa: E501
            collection_formats['platform_serial'] = 'multi'  # noqa: E501
        if 'sort' in local_var_params and local_var_params['sort'] is not None:  # noqa: E501
            query_params.append(('sort', local_var_params['sort']))  # noqa: E501
            collection_formats['sort'] = 'multi'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/prints', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PrintsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!  You can find all relevant documentation here: https://github.com/carbon3d/carbon3d-api   # noqa: E501

    The version of the OpenAPI document: 0.2.7
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import carbon3d
from carbon3d.models.printers_response import PrintersResponse  # noqa: E501
from carbon3d.rest import ApiException

class TestPrintersResponse(unittest.TestCase):
    """PrintersResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PrintersResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = carbon3d.models.printers_response.PrintersResponse()  # noqa: E501
        if include_optional :
            return PrintersResponse(
                limit = 56, 
                offset = 56, 
                total_count = 56, 
                printers = [
                    {"name":"L9001","serial":"3P01CM","hw_type":"L1","url":"https://l9001.customer.print.carbon3d.com","updated_at":"2020-03-28T12:25:00.000Z","status":{"alerts":["oxygen shortage"],"printer_state":"PRINTING","software_version":"123.0-785.85"},"prints":{"last":{"name":"great_file.stl","build_uuid":"1cf34076-417e-489f-8863-3438facd4808-10","print_id":"JN007KA","finished_at":"2020-01-18T12:25:00.000Z"},"current":{"name":"greater_file.stl","print_id":"JN008KA","build_uuid":"3ff34076-417e-489f-8863-3438facd4808-99","started_at":"2020-01-18T14:25:00.000Z","remaining_sec":523},"next":{"name":"future_file.stl","build_uuid":"66634076-417e-489f-8863-3438facd4808-09"},"queue_length":2}}
                    ]
            )
        else :
            return PrintersResponse(
                limit = 56,
                offset = 56,
                total_count = 56,
                printers = [
                    {"name":"L9001","serial":"3P01CM","hw_type":"L1","url":"https://l9001.customer.print.carbon3d.com","updated_at":"2020-03-28T12:25:00.000Z","status":{"alerts":["oxygen shortage"],"printer_state":"PRINTING","software_version":"123.0-785.85"},"prints":{"last":{"name":"great_file.stl","build_uuid":"1cf34076-417e-489f-8863-3438facd4808-10","print_id":"JN007KA","finished_at":"2020-01-18T12:25:00.000Z"},"current":{"name":"greater_file.stl","print_id":"JN008KA","build_uuid":"3ff34076-417e-489f-8863-3438facd4808-99","started_at":"2020-01-18T14:25:00.000Z","remaining_sec":523},"next":{"name":"future_file.stl","build_uuid":"66634076-417e-489f-8863-3438facd4808-09"},"queue_length":2}}
                    ],
        )

    def testPrintersResponse(self):
        """Test PrintersResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!  You can find all relevant documentation here: https://github.com/carbon3d/carbon3d-api   # noqa: E501

    The version of the OpenAPI document: 0.2.7
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import carbon3d
from carbon3d.api.applications_api import ApplicationsApi  # noqa: E501
from carbon3d.rest import ApiException


class TestApplicationsApi(unittest.TestCase):
    """ApplicationsApi unit test stubs"""

    def setUp(self):
        self.api = carbon3d.api.applications_api.ApplicationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_applications(self):
        """Test case for get_applications

        Fetch all applications summary  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!  You can find all relevant documentation here: https://github.com/carbon3d/carbon3d-api   # noqa: E501

    The version of the OpenAPI document: 0.2.7
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import carbon3d
from carbon3d.models.builds_response import BuildsResponse  # noqa: E501
from carbon3d.rest import ApiException

class TestBuildsResponse(unittest.TestCase):
    """BuildsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test BuildsResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = carbon3d.models.builds_response.BuildsResponse()  # noqa: E501
        if include_optional :
            return BuildsResponse(
                limit = 56, 
                next_cursor = 'dXNlcjpXMDdRQ1JQQTQ=', 
                total_count = 56, 
                builds = [
                    {"uuid":"98d97fe6-83d2-473c-9148-322012ea835b","parts":[{"uuid":"9962b034-e64b-4f81-a40d-26b885239a58","part_number":"B142353","model_uuid":"2ce02977-fad4-4b21-b49c-019144d945a8"}],"attachments":[{"filename":"traveler.pdf","uuid":"10d97fe6-fad4-7721-b49c-017133d945b0"}]}
                    ]
            )
        else :
            return BuildsResponse(
        )

    def testBuildsResponse(self):
        """Test BuildsResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!  You can find all relevant documentation here: https://github.com/carbon3d/carbon3d-api   # noqa: E501

    The version of the OpenAPI document: 0.2.7
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from carbon3d.configuration import Configuration


class PrinterPrints(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'last': 'PrintRef',
        'current': 'PrintRef',
        'next': 'PrintRef',
        'queue_length': 'int'
    }

    attribute_map = {
        'last': 'last',
        'current': 'current',
        'next': 'next',
        'queue_length': 'queue_length'
    }

    def __init__(self, last=None, current=None, next=None, queue_length=None, local_vars_configuration=None):  # noqa: E501
        """PrinterPrints - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._last = None
        self._current = None
        self._next = None
        self._queue_length = None
        self.discriminator = None

        if last is not None:
            self.last = last
        if current is not None:
            self.current = current
        if next is not None:
            self.next = next
        self.queue_length = queue_length

    @property
    def last(self):
        """Gets the last of this PrinterPrints.  # noqa: E501


        :return: The last of this PrinterPrints.  # noqa: E501
        :rtype: PrintRef
        """
        return self._last

    @last.setter
    def last(self, last):
        """Sets the last of this PrinterPrints.


        :param last: The last of this PrinterPrints.  # noqa: E501
        :type: PrintRef
        """

        self._last = last

    @property
    def current(self):
        """Gets the current of this PrinterPrints.  # noqa: E501


        :return: The current of this PrinterPrints.  # noqa: E501
        :rtype: PrintRef
        """
        return self._current

    @current.setter
    def current(self, current):
        """Sets the current of this PrinterPrints.


        :param current: The current of this PrinterPrints.  # noqa: E501
        :type: PrintRef
        """

        self._current = current

    @property
    def next(self):
        """Gets the next of this PrinterPrints.  # noqa: E501


        :return: The next of this PrinterPrints.  # noqa: E501
        :rtype: PrintRef
        """
        return self._next

    @next.setter
    def next(self, next):
        """Sets the next of this PrinterPrints.


        :param next: The next of this PrinterPrints.  # noqa: E501
        :type: PrintRef
        """

        self._next = next

    @property
    def queue_length(self):
        """Gets the queue_length of this PrinterPrints.  # noqa: E501


        :return: The queue_length of this PrinterPrints.  # noqa: E501
        :rtype: int
        """
        return self._queue_length

    @queue_length.setter
    def queue_length(self, queue_length):
        """Sets the queue_length of this PrinterPrints.


        :param queue_length: The queue_length of this PrinterPrints.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and queue_length is None:  # noqa: E501
            raise ValueError("Invalid value for `queue_length`, must not be `None`")  # noqa: E501

        self._queue_length = queue_length

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PrinterPrints):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PrinterPrints):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!  You can find all relevant documentation here: https://github.com/carbon3d/carbon3d-api   # noqa: E501

    The version of the OpenAPI document: 0.2.7
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import carbon3d
from carbon3d.models.part_genealogy import PartGenealogy  # noqa: E501
from carbon3d.rest import ApiException

class TestPartGenealogy(unittest.TestCase):
    """PartGenealogy unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PartGenealogy
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = carbon3d.models.part_genealogy.PartGenealogy()  # noqa: E501
        if include_optional :
            return PartGenealogy(
                build_info = carbon3d.models.part_genealogy_build_info.PartGenealogy_build_info(
                    build_uuid = '0', 
                    traveler_url = '0', 
                    slice_video_url = '0', 
                    error = '0', ), 
                print_info = carbon3d.models.part_genealogy_print_info.PartGenealogy_print_info(
                    queued_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    print_uuid = '0', 
                    printer_serial = '0', 
                    platform_serial = '0', 
                    cassette_serial = '0', 
                    resin_lot_number = '0', 
                    started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    finished_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    error = '0', )
            )
        else :
            return PartGenealogy(
        )

    def testPartGenealogy(self):
        """Test PartGenealogy"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!  You can find all relevant documentation here: https://github.com/carbon3d/carbon3d-api   # noqa: E501

    The version of the OpenAPI document: 0.2.7
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "0.2.7"

# import apis into sdk package
from carbon3d.api.applications_api import ApplicationsApi
from carbon3d.api.attachments_api import AttachmentsApi
from carbon3d.api.builds_api import BuildsApi
from carbon3d.api.models_api import ModelsApi
from carbon3d.api.part_measurement_templates_api import PartMeasurementTemplatesApi
from carbon3d.api.part_measurements_api import PartMeasurementsApi
from carbon3d.api.part_orders_api import PartOrdersApi
from carbon3d.api.parts_api import PartsApi
from carbon3d.api.print_orders_api import PrintOrdersApi
from carbon3d.api.printed_parts_api import PrintedPartsApi
from carbon3d.api.printers_api import PrintersApi
from carbon3d.api.prints_api import PrintsApi
from carbon3d.api.queues_api import QueuesApi

# import ApiClient
from carbon3d.api_client import ApiClient
from carbon3d.configuration import Configuration
from carbon3d.exceptions import OpenApiException
from carbon3d.exceptions import ApiTypeError
from carbon3d.exceptions import ApiValueError
from carbon3d.exceptions import ApiKeyError
from carbon3d.exceptions import ApiException
# import models into sdk package
from carbon3d.models.application import Application
from carbon3d.models.applications_response import ApplicationsResponse
from carbon3d.models.build import Build
from carbon3d.models.build_attachments import BuildAttachments
from carbon3d.models.builds_response import BuildsResponse
from carbon3d.models.model import Model
from carbon3d.models.model_print import ModelPrint
from carbon3d.models.models_response import ModelsResponse
from carbon3d.models.part import Part
from carbon3d.models.part_genealogy import PartGenealogy
from carbon3d.models.part_genealogy_build_info import PartGenealogyBuildInfo
from carbon3d.models.part_genealogy_print_info import PartGenealogyPrintInfo
from carbon3d.models.part_measurement import PartMeasurement
from carbon3d.models.part_measurement_response import PartMeasurementResponse
from carbon3d.models.part_measurement_template import PartMeasurementTemplate
from carbon3d.models.part_measurement_template_category_options import PartMeasurementTemplateCategoryOptions
from carbon3d.models.part_measurement_template_response import PartMeasurementTemplateResponse
from carbon3d.models.part_order import PartOrder
from carbon3d.models.part_order_request import PartOrderRequest
from carbon3d.models.part_order_request_parts import PartOrderRequestParts
from carbon3d.models.part_order_status import PartOrderStatus
from carbon3d.models.part_order_update_request import PartOrderUpdateRequest
from carbon3d.models.part_orders_response import PartOrdersResponse
from carbon3d.models.part_orders_response_part_orders import PartOrdersResponsePartOrders
from carbon3d.models.part_request import PartRequest
from carbon3d.models.parts_response import PartsResponse
from carbon3d.models.print_config import PrintConfig
from carbon3d.models.print_feedback import PrintFeedback
from carbon3d.models.print_metrics import PrintMetrics
from carbon3d.models.print_order import PrintOrder
from carbon3d.models.print_order_request import PrintOrderRequest
from carbon3d.models.print_order_routed_to import PrintOrderRoutedTo
from carbon3d.models.print_order_update_request import PrintOrderUpdateRequest
from carbon3d.models.print_orders_response import PrintOrdersResponse
from carbon3d.models.print_origin import PrintOrigin
from carbon3d.models.print_ref import PrintRef
from carbon3d.models.printed_part import PrintedPart
from carbon3d.models.printed_part_ref import PrintedPartRef
from carbon3d.models.printed_part_status import PrintedPartStatus
from carbon3d.models.printed_part_tags import PrintedPartTags
from carbon3d.models.printed_parts_response import PrintedPartsResponse
from carbon3d.models.printer import Printer
from carbon3d.models.printer_prints import PrinterPrints
from carbon3d.models.printer_queue import PrinterQueue
from carbon3d.models.printer_queue_delete_request import PrinterQueueDeleteRequest
from carbon3d.models.printer_queue_move_request import PrinterQueueMoveRequest
from carbon3d.models.printer_queue_update_response import PrinterQueueUpdateResponse
from carbon3d.models.printer_queues_response import PrinterQueuesResponse
from carbon3d.models.printer_status import PrinterStatus
from carbon3d.models.printers_response import PrintersResponse
from carbon3d.models.prints_response import PrintsResponse




# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!  You can find all relevant documentation here: https://github.com/carbon3d/carbon3d-api   # noqa: E501

    The version of the OpenAPI document: 0.2.7
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from carbon3d.configuration import Configuration


class PrinterQueueDeleteRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'action_type': 'str',
        'print_uuids': 'list[str]'
    }

    attribute_map = {
        'action_type': 'action_type',
        'print_uuids': 'print_uuids'
    }

    def __init__(self, action_type=None, print_uuids=None, local_vars_configuration=None):  # noqa: E501
        """PrinterQueueDeleteRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._action_type = None
        self._print_uuids = None
        self.discriminator = None

        self.action_type = action_type
        self.print_uuids = print_uuids

    @property
    def action_type(self):
        """Gets the action_type of this PrinterQueueDeleteRequest.  # noqa: E501


        :return: The action_type of this PrinterQueueDeleteRequest.  # noqa: E501
        :rtype: str
        """
        return self._action_type

    @action_type.setter
    def action_type(self, action_type):
        """Sets the action_type of this PrinterQueueDeleteRequest.


        :param action_type: The action_type of this PrinterQueueDeleteRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and action_type is None:  # noqa: E501
            raise ValueError("Invalid value for `action_type`, must not be `None`")  # noqa: E501
        allowed_values = ["PrinterQueueDeleteRequest"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and action_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `action_type` ({0}), must be one of {1}"  # noqa: E501
                .format(action_type, allowed_values)
            )

        self._action_type = action_type

    @property
    def print_uuids(self):
        """Gets the print_uuids of this PrinterQueueDeleteRequest.  # noqa: E501


        :return: The print_uuids of this PrinterQueueDeleteRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._print_uuids

    @print_uuids.setter
    def print_uuids(self, print_uuids):
        """Sets the print_uuids of this PrinterQueueDeleteRequest.


        :param print_uuids: The print_uuids of this PrinterQueueDeleteRequest.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and print_uuids is None:  # noqa: E501
            raise ValueError("Invalid value for `print_uuids`, must not be `None`")  # noqa: E501

        self._print_uuids = print_uuids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PrinterQueueDeleteRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PrinterQueueDeleteRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!  You can find all relevant documentation here: https://github.com/carbon3d/carbon3d-api   # noqa: E501

    The version of the OpenAPI document: 0.2.7
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from carbon3d.configuration import Configuration


class PrinterQueueMoveRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'action_type': 'str',
        'printer_serial': 'str',
        'index': 'int',
        'print_uuids': 'list[str]'
    }

    attribute_map = {
        'action_type': 'action_type',
        'printer_serial': 'printer_serial',
        'index': 'index',
        'print_uuids': 'print_uuids'
    }

    def __init__(self, action_type=None, printer_serial=None, index=None, print_uuids=None, local_vars_configuration=None):  # noqa: E501
        """PrinterQueueMoveRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._action_type = None
        self._printer_serial = None
        self._index = None
        self._print_uuids = None
        self.discriminator = None

        self.action_type = action_type
        self.printer_serial = printer_serial
        self.index = index
        self.print_uuids = print_uuids

    @property
    def action_type(self):
        """Gets the action_type of this PrinterQueueMoveRequest.  # noqa: E501


        :return: The action_type of this PrinterQueueMoveRequest.  # noqa: E501
        :rtype: str
        """
        return self._action_type

    @action_type.setter
    def action_type(self, action_type):
        """Sets the action_type of this PrinterQueueMoveRequest.


        :param action_type: The action_type of this PrinterQueueMoveRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and action_type is None:  # noqa: E501
            raise ValueError("Invalid value for `action_type`, must not be `None`")  # noqa: E501
        allowed_values = ["PrinterQueueMoveRequest"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and action_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `action_type` ({0}), must be one of {1}"  # noqa: E501
                .format(action_type, allowed_values)
            )

        self._action_type = action_type

    @property
    def printer_serial(self):
        """Gets the printer_serial of this PrinterQueueMoveRequest.  # noqa: E501

        Target printer for the move operation  # noqa: E501

        :return: The printer_serial of this PrinterQueueMoveRequest.  # noqa: E501
        :rtype: str
        """
        return self._printer_serial

    @printer_serial.setter
    def printer_serial(self, printer_serial):
        """Sets the printer_serial of this PrinterQueueMoveRequest.

        Target printer for the move operation  # noqa: E501

        :param printer_serial: The printer_serial of this PrinterQueueMoveRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and printer_serial is None:  # noqa: E501
            raise ValueError("Invalid value for `printer_serial`, must not be `None`")  # noqa: E501

        self._printer_serial = printer_serial

    @property
    def index(self):
        """Gets the index of this PrinterQueueMoveRequest.  # noqa: E501

        Target index for given uuids on target printer queue. If given 0, places the first uuid at the top of the queue, followed by other param uuids and the rest of the existing queue. If index provided is higher than the max index of the queue, add uuid(s) to the end. Use '-1' to express 'end of queue'.  # noqa: E501

        :return: The index of this PrinterQueueMoveRequest.  # noqa: E501
        :rtype: int
        """
        return self._index

    @index.setter
    def index(self, index):
        """Sets the index of this PrinterQueueMoveRequest.

        Target index for given uuids on target printer queue. If given 0, places the first uuid at the top of the queue, followed by other param uuids and the rest of the existing queue. If index provided is higher than the max index of the queue, add uuid(s) to the end. Use '-1' to express 'end of queue'.  # noqa: E501

        :param index: The index of this PrinterQueueMoveRequest.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and index is None:  # noqa: E501
            raise ValueError("Invalid value for `index`, must not be `None`")  # noqa: E501

        self._index = index

    @property
    def print_uuids(self):
        """Gets the print_uuids of this PrinterQueueMoveRequest.  # noqa: E501


        :return: The print_uuids of this PrinterQueueMoveRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._print_uuids

    @print_uuids.setter
    def print_uuids(self, print_uuids):
        """Sets the print_uuids of this PrinterQueueMoveRequest.


        :param print_uuids: The print_uuids of this PrinterQueueMoveRequest.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and print_uuids is None:  # noqa: E501
            raise ValueError("Invalid value for `print_uuids`, must not be `None`")  # noqa: E501

        self._print_uuids = print_uuids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PrinterQueueMoveRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PrinterQueueMoveRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!  You can find all relevant documentation here: https://github.com/carbon3d/carbon3d-api   # noqa: E501

    The version of the OpenAPI document: 0.2.7
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from carbon3d.configuration import Configuration


class Printer(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'serial': 'str',
        'hw_type': 'str',
        'url': 'str',
        'updated_at': 'datetime',
        'status': 'PrinterStatus',
        'prints': 'PrinterPrints'
    }

    attribute_map = {
        'name': 'name',
        'serial': 'serial',
        'hw_type': 'hw_type',
        'url': 'url',
        'updated_at': 'updated_at',
        'status': 'status',
        'prints': 'prints'
    }

    def __init__(self, name=None, serial=None, hw_type=None, url=None, updated_at=None, status=None, prints=None, local_vars_configuration=None):  # noqa: E501
        """Printer - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._serial = None
        self._hw_type = None
        self._url = None
        self._updated_at = None
        self._status = None
        self._prints = None
        self.discriminator = None

        self.name = name
        self.serial = serial
        self.hw_type = hw_type
        self.url = url
        self.updated_at = updated_at
        self.status = status
        self.prints = prints

    @property
    def name(self):
        """Gets the name of this Printer.  # noqa: E501


        :return: The name of this Printer.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Printer.


        :param name: The name of this Printer.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def serial(self):
        """Gets the serial of this Printer.  # noqa: E501


        :return: The serial of this Printer.  # noqa: E501
        :rtype: str
        """
        return self._serial

    @serial.setter
    def serial(self, serial):
        """Sets the serial of this Printer.


        :param serial: The serial of this Printer.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and serial is None:  # noqa: E501
            raise ValueError("Invalid value for `serial`, must not be `None`")  # noqa: E501

        self._serial = serial

    @property
    def hw_type(self):
        """Gets the hw_type of this Printer.  # noqa: E501


        :return: The hw_type of this Printer.  # noqa: E501
        :rtype: str
        """
        return self._hw_type

    @hw_type.setter
    def hw_type(self, hw_type):
        """Sets the hw_type of this Printer.


        :param hw_type: The hw_type of this Printer.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and hw_type is None:  # noqa: E501
            raise ValueError("Invalid value for `hw_type`, must not be `None`")  # noqa: E501

        self._hw_type = hw_type

    @property
    def url(self):
        """Gets the url of this Printer.  # noqa: E501


        :return: The url of this Printer.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this Printer.


        :param url: The url of this Printer.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and url is None:  # noqa: E501
            raise ValueError("Invalid value for `url`, must not be `None`")  # noqa: E501

        self._url = url

    @property
    def updated_at(self):
        """Gets the updated_at of this Printer.  # noqa: E501


        :return: The updated_at of this Printer.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this Printer.


        :param updated_at: The updated_at of this Printer.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    @property
    def status(self):
        """Gets the status of this Printer.  # noqa: E501


        :return: The status of this Printer.  # noqa: E501
        :rtype: PrinterStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Printer.


        :param status: The status of this Printer.  # noqa: E501
        :type: PrinterStatus
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    @property
    def prints(self):
        """Gets the prints of this Printer.  # noqa: E501


        :return: The prints of this Printer.  # noqa: E501
        :rtype: PrinterPrints
        """
        return self._prints

    @prints.setter
    def prints(self, prints):
        """Sets the prints of this Printer.


        :param prints: The prints of this Printer.  # noqa: E501
        :type: PrinterPrints
        """
        if self.local_vars_configuration.client_side_validation and prints is None:  # noqa: E501
            raise ValueError("Invalid value for `prints`, must not be `None`")  # noqa: E501

        self._prints = prints

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Printer):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Printer):
            return True

        return self.to_dict() != other.to_dict()
